@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -33,7 +33,9 @@ from lollypop.define import LOLLYPOP_DATA_PATH, StorageType
 from lollypop.database import Database
 from lollypop.player import Player
 from lollypop.inhibitor import Inhibitor
-from lollypop.art import Art
+from lollypop.artwork import Artwork
+from lollypop.artwork_album import AlbumArtwork
+from lollypop.artwork_artist import ArtistArtwork
 from lollypop.logger import Logger
 from lollypop.ws_director import DirectorWebService
 from lollypop.sqlcursor import SqlCursor
@@ -58,17 +60,19 @@ class Application(Gtk.Application, ApplicationActions, ApplicationCmdline):
             - Create main window
     """
 
-    def __init__(self, version, data_dir):
+    def __init__(self, version, data_dir, app_id):
         """
             Create application
             @param version as str
             @param data_dir as str
+            @param app_id as str
         """
         Gtk.Application.__init__(
             self,
-            application_id="org.gnome.Lollypop",
+            application_id=app_id,
             flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE)
         ApplicationCmdline.__init__(self, version)
+        self.__app_id = app_id
         self.__data_dir = data_dir
         self.set_property("register-session", True)
         signal(SIGINT, lambda a, b: self.quit())
@@ -81,18 +85,14 @@ class Application(Gtk.Application, ApplicationActions, ApplicationCmdline):
         GLib.setenv("PULSE_PROP_media.role", "music", True)
         GLib.setenv("PULSE_PROP_application.icon_name",
                     "org.gnome.Lollypop", True)
-        # Ideally, we will be able to delete this once Flatpak has a solution
-        # for SSL certificate management inside of applications.
+        # Flatpak hacks
         if GLib.file_test("/app", GLib.FileTest.EXISTS):
-            paths = ["/etc/ssl/certs/ca-certificates.crt",
-                     "/etc/pki/tls/cert.pem",
-                     "/etc/ssl/cert.pem"]
-            for path in paths:
-                if GLib.file_test(path, GLib.FileTest.EXISTS):
-                    GLib.setenv("SSL_CERT_FILE", path, True)
-                    break
+            # Set /tmp for GLib, /tmp not accessible in flatpak
+            tmp = GLib.environ_getenv(GLib.get_environ(), "XDG_RUNTIME_DIR")
+            GLib.setenv("TMPDIR", "%s/app/org.gnome.Lollypop" % tmp, True)
         self.cursors = {}
         self.shown_sidebar_tooltip = False
+        self.system_supports_color_schemes = False
         self.__window = None
         self.__fs_window = None
         settings = Gio.Settings.new("org.gnome.desktop.interface")
@@ -132,6 +132,15 @@ class Application(Gtk.Application, ApplicationActions, ApplicationCmdline):
         styleContext = Gtk.StyleContext()
         styleContext.add_provider_for_screen(screen, cssProvider,
                                              Gtk.STYLE_PROVIDER_PRIORITY_USER)
+        # Devel version, load devel theme
+        if self.__app_id is None:
+            css = "*:selected{ background-color: red; }"
+            cssProvider = Gtk.CssProvider()
+            cssProvider.load_from_data(css.encode("utf-8"))
+            screen = Gdk.Screen.get_default()
+            styleContext = Gtk.StyleContext()
+            styleContext.add_provider_for_screen(
+                screen, cssProvider, Gtk.STYLE_PROVIDER_PRIORITY_USER + 1)
         self.db = Database()
         self.cache = CacheDatabase()
         self.playlists = Playlists()
@@ -145,8 +154,10 @@ class Application(Gtk.Application, ApplicationActions, ApplicationCmdline):
         self.notify = NotificationManager()
         self.task_helper = TaskHelper()
         self.art_helper = ArtHelper()
-        self.art = Art()
+        self.art = Artwork()
         self.art.update_art_size()
+        self.album_art = AlbumArtwork()
+        self.artist_art = ArtistArtwork()
         self.ws_director = DirectorWebService()
         self.ws_director.start()
         if not self.settings.get_value("disable-mpris"):
@@ -154,11 +165,17 @@ class Application(Gtk.Application, ApplicationActions, ApplicationCmdline):
             MPRIS(self)
 
         settings = Gtk.Settings.get_default()
-        self.__gtk_dark = settings.get_property(
-            "gtk-application-prefer-dark-theme")
-        if not self.__gtk_dark:
-            dark = self.settings.get_value("dark-ui")
-            settings.set_property("gtk-application-prefer-dark-theme", dark)
+        manager = Handy.StyleManager.get_default()
+        if manager.get_system_supports_color_schemes():
+            self.system_supports_color_schemes = True
+            manager.set_color_scheme(Handy.ColorScheme.PREFER_LIGHT)
+        else:
+            self.__gtk_dark = settings.get_property(
+                "gtk-application-prefer-dark-theme")
+            if not self.__gtk_dark:
+                dark = self.settings.get_value("dark-ui")
+                settings.set_property(
+                    "gtk-application-prefer-dark-theme", dark)
         ApplicationActions.__init__(self)
         monitor = Gio.NetworkMonitor.get_default()
         if monitor.get_network_available() and\
@@ -181,16 +198,20 @@ class Application(Gtk.Application, ApplicationActions, ApplicationCmdline):
             self.__window.show()
             self.player.restore_state()
 
-    def quit(self, vacuum=False):
+    def quit(self, vacuum=False, wait=100):
         """
             Quit Lollypop
             @param vacuum as bool
+            @param wait as int
         """
         self.__window.container.stop()
         self.__window.hide()
-        if not self.ws_director.stop():
-            GLib.timeout_add(100, self.quit, vacuum)
+        # Force stop after some tries
+        if wait < 1000 and not self.ws_director.stop():
+            GLib.timeout_add(wait, self.quit, vacuum, wait + 100)
             return
+        self.album_art.cancellable.cancel()
+        self.artist_art.cancellable.cancel()
         if self.settings.get_value("save-state"):
             self.__window.container.stack.save_history()
         # Then vacuum db
@@ -288,14 +309,6 @@ class Application(Gtk.Application, ApplicationActions, ApplicationCmdline):
         """
         return self.__data_dir
 
-    @property
-    def gtk_application_prefer_dark_theme(self):
-        """
-            Return default gtk value
-            @return bool
-        """
-        return self.__gtk_dark
-
 #######################
 # PRIVATE             #
 #######################
