@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -28,10 +28,9 @@ class AlbumsDecadeWidget(RoundedAlbumsWidget):
             @param view_type as ViewType
             @param font_height as int
         """
-        self.__font_height = font_height
         decade_str = "%s - %s" % (item_ids[0], item_ids[-1])
         RoundedAlbumsWidget.__init__(self, item_ids, decade_str,
-                                     decade_str, view_type)
+                                     decade_str, view_type, font_height)
         self._genre = Type.YEARS
 
     def populate(self):
@@ -43,15 +42,6 @@ class AlbumsDecadeWidget(RoundedAlbumsWidget):
         else:
             self.set_artwork()
 
-    def set_view_type(self, view_type):
-        """
-            Update view type
-            @param view_type as ViewType
-        """
-        RoundedAlbumsWidget.set_view_type(self, view_type)
-        self.set_size_request(self._art_size,
-                              self._art_size + self.__font_height)
-
     @property
     def artwork_name(self):
         """
@@ -69,18 +59,19 @@ class AlbumsDecadeWidget(RoundedAlbumsWidget):
             @return [int]
         """
         storage_type = get_default_storage_type()
-        album_ids = []
+        items = []
         for year in self._data:
-            album_ids += App().albums.get_albums_for_year(year,
-                                                          storage_type,
-                                                          self._ALBUMS_COUNT)
-            l = len(album_ids)
-            if l < self._ALBUMS_COUNT:
-                album_ids += App().albums.get_compilations_for_year(
+            items += App().tracks.get_albums_by_disc_for_year(
                                                        year,
-                                                       storage_type,
+                                                       storage_type, True,
                                                        self._ALBUMS_COUNT)
-        return album_ids
+            l = len(items)
+            if l < self._ALBUMS_COUNT:
+                items += App().tracks.get_compilations_by_disc_for_year(
+                                                       year,
+                                                       storage_type, True,
+                                                       self._ALBUMS_COUNT)
+        return [item[0] for item in items]
 
 #######################
 # PRIVATE             #
