@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -10,14 +10,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib
+from gi.repository import Gtk, Gio, GLib
 
 from gettext import gettext as _
 from random import choice
 
 from lollypop.utils import set_cursor_type, on_query_tooltip, popup_widget
 from lollypop.utils_artist import add_artist_to_playback, play_artists
-from lollypop.define import App, ArtSize, ArtBehaviour, ViewType, Size
+from lollypop.define import App, ArtSize, ArtBehaviour, ViewType
 from lollypop.widgets_banner import BannerWidget
 from lollypop.helper_signals import SignalsHelper, signals_map
 
@@ -44,6 +44,7 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         builder.add_from_resource("/org/gnome/Lollypop/ArtistBannerWidget.ui")
         builder.connect_signals(self)
         self.__badge_artwork = builder.get_object("badge_artwork")
+        self.__labels = builder.get_object("label_event")
         self.__title_label = builder.get_object("artist")
         self.__title_label.connect("realize", set_cursor_type)
         self.__title_label.connect("query-tooltip", on_query_tooltip)
@@ -55,9 +56,8 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             self.__menu_button.hide()
         builder.get_object("artwork_event").connect(
             "realize", set_cursor_type)
-        builder.get_object("label_event").connect(
-            "realize", set_cursor_type)
-        widget = builder.get_object("widget")
+        self.__labels.connect("realize", set_cursor_type)
+        self.__widget = builder.get_object("widget")
         artists = []
         for artist_id in self.__artist_ids:
             artists.append(App().artists.get_name(artist_id))
@@ -65,13 +65,19 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             ", ".join(artists)))
         self.__show_artwork = len(artist_ids) == 1
         self.__title_label.get_style_context().add_class("text-x-large")
-        self._overlay.add_overlay(widget)
-        self._overlay.set_overlay_pass_through(widget, True)
+        self._overlay.add_overlay(self.__widget)
+        self._overlay.set_overlay_pass_through(self.__widget, True)
         self.__update_add_button()
+        self.__set_internal_size()
         return [
-               (App().art, "artist-artwork-changed",
+               (App().window.container.widget, "notify::folded",
+                "_on_container_folded"),
+               (App().artist_art, "artist-artwork-changed",
                 "_on_artist_artwork_changed"),
-               (App().player, "playback-changed", "_on_playback_changed"),
+               (App().player, "playback-added", "_on_playback_changed"),
+               (App().player, "playback-updated", "_on_playback_changed"),
+               (App().player, "playback-setted", "_on_playback_changed"),
+               (App().player, "playback-removed", "_on_playback_changed"),
                (App().settings, "changed::artist-artwork",
                 "_on_artist_artwork_setting_changed")
 
@@ -84,7 +90,6 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         """
         BannerWidget.update_for_width(self, width)
         self.__set_artwork()
-        self.__set_internal_size()
 
 #######################
 # PROTECTED           #
@@ -96,7 +101,14 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         """
         if BannerWidget._handle_width_allocate(self, allocation):
             self.__set_artwork()
-            self.__set_internal_size()
+
+    def _on_container_folded(self, leaflet, folded):
+        """
+            Handle libhandy folded status
+            @param leaflet as Handy.Leaflet
+            @param folded as Gparam
+        """
+        self.__set_internal_size()
 
     def _on_artist_artwork_setting_changed(self, settings, variant):
         """
@@ -141,17 +153,24 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         from lollypop.widgets_menu import MenuBuilder
         from lollypop.menu_artist import ArtistMenu
         from lollypop.menu_similars import SimilarsMenu
+        from lollypop.menu_artwork import ArtistArtworkMenu
         menu = ArtistMenu(self.__artist_ids[0],
                           self.__storage_type,
                           self.view_type,
-                          App().window.is_adaptive)
+                          App().window.folded)
         menu_widget = MenuBuilder(menu, False)
         menu_widget.show()
-        menu_ext = SimilarsMenu()
+        menu_ext = SimilarsMenu(self.__artist_ids[0])
         menu_ext.show()
-        menu_ext.populate(self.__artist_ids[0])
-        menu_widget.append_widget(menu_ext)
-        popup_widget(menu_widget, button)
+        menu_widget.add_widget(menu_ext)
+        if App().window.folded:
+            menu_ext2 = ArtistArtworkMenu(self.__artist_ids[0],
+                                          self.view_type,
+                                          True)
+            menu_ext2.connect("hidden", self.__close_artwork_menu)
+            menu_ext2.show()
+            menu_widget.add_widget(menu_ext2)
+        popup_widget(menu_widget, button, None, None, button)
 
     def _on_badge_button_release(self, eventbox, event):
         """
@@ -159,13 +178,23 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             @param eventbox as Gtk.EventBox
             @param event as Gdk.Event
         """
-        from lollypop.widgets_artwork_artist import ArtistArtworkSearchWidget
-        artwork_search = ArtistArtworkSearchWidget(self.__artist_ids[0],
-                                                   self.view_type)
-        artwork_search.show()
-        # Let current animation run
-        GLib.timeout_add(250, artwork_search.populate)
-        popup_widget(artwork_search, eventbox)
+        from lollypop.widgets_menu import MenuBuilder
+        from lollypop.menu_artwork import ArtistArtworkMenu
+        menu = Gio.Menu()
+        if App().window.folded:
+            from lollypop.menu_header import ArtistMenuHeader
+            menu.append_item(ArtistMenuHeader(self.__artist_ids[0]))
+        menu_widget = MenuBuilder(menu, False)
+        menu_widget.show()
+        menu_ext = ArtistArtworkMenu(self.__artist_ids[0],
+                                     self.view_type,
+                                     False)
+        menu_ext.connect("hidden", self.__close_artwork_menu)
+        menu_ext.show()
+        menu_widget.add_widget(menu_ext)
+        self.__artwork_popup = popup_widget(menu_widget,
+                                            eventbox,
+                                            None, None, None)
 
     def _on_artist_artwork_changed(self, art, prefix):
         """
@@ -179,16 +208,21 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
                 self.__set_artwork()
                 self.__set_internal_size()
 
-    def _on_playback_changed(self, player):
+    def _on_playback_changed(self, *ignore):
         """
             Update add button
-            @param player as Player
         """
         self.__update_add_button()
 
 #######################
 # PRIVATE             #
 #######################
+    def __close_artwork_menu(self, action, variant):
+        if App().window.folded:
+            App().window.container.go_back()
+        else:
+            self.__artwork_popup.destroy()
+
     def __set_artwork(self):
         """
             Set artwork
@@ -206,6 +240,13 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
                                         self._on_artwork)
         else:
             self._artwork.get_style_context().add_class("default-banner")
+        if self.width < ArtSize.BANNER * 3:
+            if self.__widget.get_child_at(1, 0) == self.__labels:
+                self.__widget.remove(self.__labels)
+                self.__widget.attach(self.__labels, 2, 2, 3, 1)
+        elif self.__widget.get_child_at(2, 2) == self.__labels:
+            self.__widget.remove(self.__labels)
+            self.__widget.attach(self.__labels, 1, 0, 1, 3)
 
     def __set_badge_artwork(self, art_size):
         """
@@ -236,28 +277,21 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
         title_context = self.__title_label.get_style_context()
         for c in title_context.list_classes():
             title_context.remove_class(c)
-        if self.width <= Size.SMALL:
-            art_size = None
-            cls = "text-medium"
-        elif self.width <= Size.MEDIUM:
+        if App().window.folded:
             art_size = ArtSize.MEDIUM
             cls = "text-large"
         else:
             art_size = ArtSize.BANNER
-            cls = "text-xx-large"
+            cls = "text-x-large"
         self.__title_label.get_style_context().add_class(cls)
-        if art_size is None:
-            self.__badge_artwork.hide()
-        else:
-            self.__badge_artwork.show()
-            self.__set_badge_artwork(art_size)
+        self.__set_badge_artwork(art_size)
 
     def __update_add_button(self):
         """
             Set image as +/-
         """
-        album_ids = App().albums.get_ids(self.__artist_ids, self.__genre_ids,
-                                         self.__storage_type)
+        album_ids = App().albums.get_ids(self.__genre_ids, self.__artist_ids,
+                                         self.__storage_type, False)
         add = set(App().player.album_ids) & set(album_ids) != set(album_ids)
         if add:
             # Translators: artist context
@@ -279,8 +313,6 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             @param surface as cairo.Surface
             @param art_size as int
         """
-        if self.get_allocated_width() >= Size.MEDIUM / 1.5:
-            self.__badge_artwork.show()
         if surface is None:
             self.__badge_artwork.get_style_context().add_class("circle-icon")
             self.__badge_artwork.set_size_request(art_size, art_size)
@@ -291,4 +323,3 @@ class ArtistBannerWidget(BannerWidget, SignalsHelper):
             self.__badge_artwork.get_style_context().remove_class(
                 "circle-icon")
             self.__badge_artwork.set_from_surface(surface)
-            del surface
